#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# This file contains the list of cmss supported by CMSeeK in the following structure
# ExampleCMS = {
#'name':'Example CMS',
#'url':'https://examplecms.com',
#'vd':'true',
#'deeps':'false'
#}

# vd determines if CMSeek can detect the version of the CMS and deeps determines if there's a deepscan available for the cms

wp = {
    'name':'WordPress',
    'url':'https://wordpress.org',
    'vd':'1',
    'deeps':'1'
}

tilda = {
    'name':'Tilda CMS',
    'url':'https://tilda.cc/',
    'vd':'0',
    'deeps':'0'
}

mg = {
    'name':'Magento',
    'url':'https://magento.com',
    'vd':'1',
    'deeps':'0'
}

blg = {
    'name':'Blogger By Google',
    'url':'https://blogger.com',
    'vd':'0',
    'deeps':'0'
}

ghost = {
    'name':'Ghost CMS',
    'url':'https://ghost.org',
    'vd':'0',
    'deeps':'0'
}

lj = {
    'name':'LiveJournal',
    'url':'https://livejournal.com',
    'vd':'0',
    'deeps':'0'
}

tdc = {
    'name':'3dCart',
    'url':'https://3dcart.com',
    'vd':'0',
    'deeps':'0'
}

amcms = {
    'name':'Ametys CMS',
    'url':'https://ametys.org',
    'vd':'0',
    'deeps':'0'
}

apos = {
    'name':'Apostrophe CMS',
    'url':'https://apostrophecms.org',
    'vd':'0',
    'deeps':'0'
}

asciid = {
    'name':'AsciiDoc',
    'url':'https://methods.co.nz',
    'vd':'0',
    'deeps':'0'
}

dru = {
    'name':'Drupal',
    'url':'https://drupal.org',
    'vd':'1',
    'deeps':'0'
}

zyro = {
    'name':'Zyro',
    'url':'https://zyro.com/',
    'vd':'0',
    'deeps':'0'
}

bolt = {
    'name':'Bolt',
    'url':'https://bolt.com',
    'vd':'0',
    'deeps':'0'
}

brcms = {
    'name':'BrowserCMS',
    'url':'https://browsercms.com',
    'vd':'1',
    'deeps':'0'
}

bubble = {
    'name':'Bubble',
    'url':'https://bubble.is',
    'vd':'0',
    'deeps':'0'
}

abc = {
    'name':'Adobe Business Catalyst',
    'url':'https://businesscatalyst.com',
    'vd':'0',
    'deeps':'0'
}

ckan = {
    'name':'CKAN',
    'url':'https://ckan.org',
    'vd':'0',
    'deeps':'0'
}

cmds = {
    'name':'CMS Made Simple',
    'url':'https://cmsmadesimple.org',
    'vd':'0',
    'deeps':'0'
}

csim = {
    'name':'CMSimple',
    'url':'https://cmssimple.org',
    'vd':'1',
    'deeps':'0'
}

xe = {
    'name':'XpressEngine',
    'url':'https://xpressengine.com',
    'vd':'1',
    'deeps':'0'
}

tp3 = {
    'name':'TYPO3 CMS',
    'url':'https://typo3.org',
    'vd':'0',
    'deeps':'0'
}

tpc = {
    'name':'Textpattern CMS',
    'url':'https://textpattern.com',
    'vd':'0',
    'deeps':'0'
}

joom = {
    'name':'Joomla',
    'url':'https://joomla.org',
    'vd':'1',
    'deeps':'1'
}
oc = {
    'name':'OpenCart',
    'url':'https://www.opencart.com',
    'vd':'0',
    'deeps':'0'
}
xoops = {
    'name':'XOOPS',
    'url':'http://xoops.org',
    'vd':'0',
    'deeps':'0'
}
ushahidi = {
    'name':'Ushahidi',
    'url':'http://www.ushahidi.com',
    'vd':'0',
    'deeps':'0'
}
umi = {
    'name':'UMI.CMS',
    'url':'https://www.umi-cms.ru',
    'vd':'1',
    'deeps':'0'
}
tiki = {
    'name':'Tiki Wiki CMS Groupware',
    'url':'http://tiki.org',
    'vd':'0',
    'deeps':'0'
}
wolf = {
    'name':'Wolf CMS',
    'url':'http://www.wolfcms.org',
    'vd':'0',
    'deeps':'0'
}
wix = {
    'name':'WIX Website Builder',
    'url':'http://wix.com',
    'vd':'0',
    'deeps':'0'
}
wb = {
    'name':'WebsiteBaker CMS',
    'url':'https://websitebaker.org/',
    'vd':'0',
    'deeps':'0'
}
wgui = {
    'name':'WebGUI',
    'url':'http://www.webgui.org',
    'vd':'1',
    'deeps':'0'
}
tidw = {
    'name':'TiddlyWiki',
    'url':'https://tiddlywiki.com/',
    'vd':'1',
    'deeps':'0'
}
sulu = {
    'name':'SULU',
    'url':'https://sulu.io/',
    'vd':'1',
    'deeps':'0'
}
subcms = {
    'name':'Subrion CMS',
    'url':'https://subrion.org/',
    'vd':'1',
    'deeps':'0'
}
sqm = {
    'name':'Squiz Matrix',
    'url':'https://www.squiz.net/technology/cms',
    'vd':'0',
    'deeps':'0'
}
spin = {
    'name':'Spin CMS',
    'url':'https://www.spin.cw/',
    'vd':'0',
    'deeps':'0'
}
sdev = {
    'name':'solodev',
    'url':'https://www.solodev.com/',
    'vd':'0',
    'deeps':'0'
}
snews = {
    'name':'sNews',
    'url':'https://snewscms.com/',
    'vd':'1',
    'deeps':'0'
}
score = {
    'name':'Sitecore',
    'url':'https://www.sitecore.com/',
    'vd':'0',
    'deeps':'0'
}
sim = {
    'name':'SIMsite',
    'url':'https://simgroep.nl/',
    'vd':'0',
    'deeps':'0'
}
spb = {
    'name':'Simplébo',
    'url':'https://www.simplebo.fr',
    'vd':'0',
    'deeps':'0'
}
sst = {
    'name':'SilverStripe',
    'url':'https://www.silverstripe.org/',
    'vd':'0',
    'deeps':'0'
}
silva = {
    'name':'Silva CMS',
    'url':'http://infrae.com/products/silva',
    'vd':'0',
    'deeps':'0'
}
dle = {
    'name':'DataLife Engine',
    'url':'https://dle-news.com',
    'vd':'0',
    'deeps':'0'
}
spity = {
    'name':'Serendipity',
    'url':'https://docs.s9y.org/',
    'vd':'1',
    'deeps':'0'
}
rcube = {
    'name':'RoundCube Webmail',
    'url':'https://roundcube.net/',
    'vd':'0',
    'deeps':'0'
}
slcms = {
    'name':'SeamlessCMS',
    'url':'https://www.seamlesscms.com/',
    'vd':'1',
    'deeps':'0'
}
rock = {
    'name':'Rock RMS',
    'url':'https://www.rockrms.com/',
    'vd':'1',
    'deeps':'0'
}
roadz = {
    'name':'Roadiz CMS',
    'url':'https://www.roadiz.io/',
    'vd':'1',
    'deeps':'0'
}
rite = {
    'name':'RiteCMS',
    'url':'http://ritecms.com/',
    'vd':'1',
    'deeps':'0'
}
rcms = {
    'name':'RCMS',
    'url':'https://www.reallycms.fi/',
    'vd':'0',
    'deeps':'0'
}
quick = {
    'name':'Quick.Cms',
    'url':'https://opensolution.org/cms-system-quick-cms.html',
    'vd':'1',
    'deeps':'0'
}
pcore = {
    'name':'Pimcore',
    'url':'https://pimcore.com/',
    'vd':'0',
    'deeps':'0'
}
pwind = {
    'name':'phpWind',
    'url':'https://www.phpwind.com/',
    'vd':'1',
    'deeps':'0'
}
phpc = {
    'name':'phpCMS',
    'url':'http://www.phpcms.cn/',
    'vd':'0',
    'deeps':'0'
}
percms = {
    'name':'Percussion CMS',
    'url':'https://www.percussion.com/',
    'vd':'0',
    'deeps':'0'
}
pblue = {
    'name':'PencilBlue',
    'url':'http://pencilblue.org',
    'vd':'0',
    'deeps':'0'
}
ophal =  {
    'name':'Ophal',
    'url':'http://ophal.org',
    'vd':'1',
    'deeps':'0'
}
sfy =  {
    'name':'Sitefinity',
    'url':'https://www.sitefinity.com/',
    'vd':'1',
    'deeps':'0'
}
otwsm = {
    'name':'OpenText WSM',
    'url':'http://www.opentext.com/',
    'vd':'1',
    'deeps':'0'
}
ocms = {
    'name':'OpenCms',
    'url':'http://www.opencms.org/',
    'vd':'1',
    'deeps':'0'
}
odoo = {
    'name':'Odoo',
    'url':'https://www.odoo.com/',
    'vd':'0',
    'deeps':'0'
}
share = {
    'name':'Microsoft Sharepoint',
    'url':'https://sharepoint.com',
    'vd':'1',
    'deeps':'0'
}
octcms = {
    'name':'October CMS',
    'url':'https://octobercms.com/',
    'vd':'0',
    'deeps':'0'
}
mura = {
    'name':'Mura CMS',
    'url':'http://www.getmura.com/',
    'vd':'1',
    'deeps':'0'
}

moto = {
    'name':'Moto CMS',
    'url':'https://www.motocms.com/',
    'vd':'0',
    'deeps':'0'
}

mnet = {
    'name':'Mono.net',
    'url':'https://mono.net',
    'vd':'0',
    'deeps':'0'
}

modx = {
    'name':'MODX',
    'url':'https://modx.com/',
    'vd':'0',
    'deeps':'0'
}

methd = {
    'name':'Methode',
    'url':'https://www.eidosmedia.com',
    'vd':'0',
    'deeps':'0'
}

mambo = {
    'name':'Mambo',
    'url':'http://mambo-foundation.org',
    'vd':'0',
    'deeps':'0'
}

lscms = {
    'name':'LiveStreet CMS',
    'url':'http://livestreetcms.com/',
    'vd':'0',
    'deeps':'0'
}

lepton = {
    'name':'LEPTON CMS',
    'url':'https://lepton-cms.org/',
    'vd':'0',
    'deeps':'0'
}

kbcms = {
    'name':'Kooboo CMS',
    'url':'https://www.kooboo.com/',
    'vd':'1',
    'deeps':'0'
}

koken = {
    'name':'Koken',
    'url':'http://koken.me',
    'vd':'1',
    'deeps':'0'
}

jimdo = {
    'name':'Jimdo',
    'url':'https://www.jimdo.com/',
    'vd':'0',
    'deeps':'0'
}

ibit = {
    'name':'Indexhibit',
    'url':'http://www.indexhibit.org/',
    'vd':'0',
    'deeps':'0'
}

wflow = {
    'name':'Webflow CMS',
    'url':'https://webflow.com/',
    'vd':'0',
    'deeps':'0'
}

jcms = {
    'name':'Jalios JCMS',
    'url':'http://www.jalios.com/',
    'vd':'0',
    'deeps':'0'
}
impage = {
    'name':'ImpressPages CMS',
    'url':'https://www.impresspages.org/',
    'vd':'1',
    'deeps':'0'
}
hotaru = {
    'name':'Hotaru CMS',
    'url':'http://hotarucms.org/',
    'vd':'0',
    'deeps':'0'
}
hippo = {
    'name':'HIPPO CMS',
    'url':'https://www.onehippo.org/',
    'vd':'0',
    'deeps':'0'
}
grav = {
    'name':'GravCMS',
    'url':'https://getgrav.org/',
    'vd':'0',
    'deeps':'0'
}
gsimp = {
    'name':'GetSimple CMS',
    'url':'http://get-simple.info/',
    'vd':'0',
    'deeps':'0'
}
fork = {
    'name':'Fork CMS',
    'url':'https://www.fork-cms.com/',
    'vd':'0',
    'deeps':'0'
}
phpn = {
    'name':'PHP Nuke',
    'url':'https://www.phpnuke.org/',
    'vd':'0',
    'deeps':'0'
}
flex = {
    'name':'FlexCMP',
    'url':'https://www.flexcmp.com',
    'vd':'1',
    'deeps':'0'
}
ezpu = {
    'name':'eZ Publish',
    'url':'https://ez.no/',
    'vd':'0',
    'deeps':'0'
}
exen = {
    'name':'ExpressionEngine',
    'url':'https://expressionengine.com/',
    'vd':'0',
    'deeps':'0'
}
epis = {
    'name':'EPiServer',
    'url':'https://www.episerver.com/',
    'vd':'0',
    'deeps':'0'
}
e107 = {
    'name':'e107',
    'url':'https://e107.org/',
    'vd':'0',
    'deeps':'0'
}
dnn = {
    'name':'DNN Platform',
    'url':'http://www.dnnsoftware.com',
    'vd':'0',
    'deeps':'0'
}
phpbb = {
    'name':'phpBB',
    'url':'http://phpbb.com',
    'vd':'0',
    'deeps':'0'
}
dede = {
    'name':'DEDE CMS',
    'url':'http://dedecms.com/',
    'vd':'0',
    'deeps':'0'
}
dncms = {
    'name':'Danneo CMS',
    'url':'http://danneo.ru/',
    'vd':'1',
    'deeps':'0'
}
craft = {
    'name':'Craft CMS',
    'url':'https://craftcms.com/',
    'vd':'0',
    'deeps':'0'
}
dragon = {
    'name':'CPG Dragonfly',
    'url':'https://dragonflycms.org/',
    'vd':'0',
    'deeps':'0'
}
coton = {
    'name':'Cotonti',
    'url':'https://www.cotonti.com/',
    'vd':'0',
    'deeps':'0'
}
orchd = {
    'name':'Orchard CMS',
    'url':'https://orchardproject.net/',
    'vd':'0',
    'deeps':'0'
}
cbox = {
    'name':'ContentBox',
    'url':'https://www.contentboxcms.org/',
    'vd':'0',
    'deeps':'0'
}
conful = {
    'name':'Contentful',
    'url':'https://www.contentful.com/',
    'vd':'0',
    'deeps':'0'
}
cntsis = {
    'name':'Contensis CMS',
    'url':'https://zengenti.com/',
    'vd':'1',
    'deeps':'0'
}
cnido = {
    'name':'CMS CONTENIDO',
    'url':'https://www.contenido.org/',
    'vd':'1',
    'deeps':'0'
}
contao = {
    'name':'Contao CMS',
    'url':'https://contao.org/en/',
    'vd':'0',
    'deeps':'0'
}
con5 = {
    'name':'Concrete5 CMS',
    'url':'https://www.concrete5.org/',
    'vd':'1',
    'deeps':'0'
}
arc = {
    'name':'Arc Forum',
    'url':'http://arclanguage.org/',
    'vd':'0',
    'deeps':'0'
}
bboard = {
    'name':'Burning Board',
    'url':'https://www.woltlab.com/',
    'vd':'1',
    'deeps':'0'
}
dscrs = {
    'name':'Discourse',
    'url':'https://www.discourse.org/',
    'vd':'1',
    'deeps':'0'
}
discuz = {
    'name':'Discuz!',
    'url':'http://www.discuz.net/',
    'vd':'1',
    'deeps':'0'
}
flarum = {
    'name':'Flarum',
    'url':'https://flarum.org/',
    'vd':'0',
    'deeps':'0'
}
fluxbb = {
    'name':'FluxBB',
    'url':'https://fluxbb.org/',
    'vd':'0',
    'deeps':'0'
}
ipb = {
    'name':'IP.Board community forum',
    'url':'https://www.invisioncommunity.com/',
    'vd':'0',
    'deeps':'0'
}
minibb = {
    'name':'miniBB',
    'url':'http://www.minibb.com/',
    'vd':'1',
    'deeps':'0'
}
mybb = {
    'name':'MyBB',
    'url':'https://mybb.com/',
    'vd':'1',
    'deeps':'0'
}
nodebb = {
    'name':'NodeBB',
    'url':'https://nodebb.org/',
    'vd':'1',
    'deeps':'0'
}
punbb = {
    'name':'PunBB',
    'url':'http://punbb.informer.com/',
    'vd':'1',
    'deeps':'0'
}
smf = {
    'name':'Simple Machines Forum',
    'url':'http://simplemachines.org/',
    'vd':'1',
    'deeps':'0'
}
vanilla = {
    'name':'Vanilla Forums',
    'url':'https://vanillaforums.com',
    'vd':'1',
    'deeps':'0'
}
uknva = {
    'name':'uKnowva',
    'url':'https://uknowva.com/',
    'vd':'1',
    'deeps':'0'
}
xf = {
    'name':'XenForo',
    'url':'https://xenforo.com/',
    'vd':'0',
    'deeps':'0'
}
xmb = {
    'name':'XMB',
    'url':'https://www.xmbforum.com/',
    'vd':'1',
    'deeps':'0'
}
yabb = {
    'name':'YaBB (Yet another Bulletin Board)',
    'url':'http://www.yabbforum.com/',
    'vd':'1',
    'deeps':'0'
}
aef = {
    'name':'Advanced Electron Forum',
    'url':'http://www.anelectron.com/',
    'vd':'1',
    'deeps':'0'
}
bhf = {
    'name':'Beehive Forum',
    'url':'https://www.beehiveforum.co.uk/',
    'vd':'1',
    'deeps':'0'
}
fudf = {
    'name':'FUDforum',
    'url':'http://fudforum.org/forum/',
    'vd':'1',
    'deeps':'0'
}
phorum = {
    'name':'Phorum',
    'url':'https://www.phorum.org/',
    'vd':'0',
    'deeps':'0'
}
yaf = {
    'name':'Yet Another Forum (YAF)',
    'url':'http://www.yetanotherforum.net',
    'vd':'1',
    'deeps':'0'
}
yazd = {
    'name':'Yazd',
    'url':'http://www.forumsoftware.ca/',
    'vd':'0',
    'deeps':'0'
}
ubbt = {
    'name':'UBB.threads',
    'url':'http://www.ubbcentral.com/',
    'vd':'1',
    'deeps':'0'
}
nnf = {
    'name':'NoNonsense Forum',
    'url':'http://camendesign.com/nononsense_forum',
    'vd':'0',
    'deeps':'0'
}
myupb = {
    'name':'myUPB',
    'url':'http://www.myupb.com',
    'vd':'1',
    'deeps':'0'
}
mvnf = {
    'name':'mvnForum',
    'url':'https://sourceforge.net/projects/mvnforum/',
    'vd':'1',
    'deeps':'0'
}
mwf = {
    'name':'mwForum',
    'url':'https://www.mwforum.org/',
    'vd':'0',
    'deeps':'0'
}
mcb = {
    'name':'MercuryBoard',
    'url':'http://www.mercuryboard.com/',
    'vd':'1',
    'deeps':'0'
}
aspf = {
    'name':'AspNetForum',
    'url':'https://www.jitbit.com/asp-net-forum/',
    'vd':'1',
    'deeps':'0'
}
jf = {
    'name':'JForum',
    'url':'http://www.jforum.net/',
    'vd':'1',
    'deeps':'0'
}
afsto = {
    'name':'Afosto',
    'url':'https://afosto.com/',
    'vd':'0',
    'deeps':'0'
}
abuy = {
    'name':'Afterbuy',
    'url':'https://www.afterbuy.de',
    'vd':'0',
    'deeps':'0'
}
arstta = {
    'name':'Arastta',
    'url':'https://arastta.org/',
    'vd':'0',
    'deeps':'0'
}
bigc = {
    'name':'BigCommerce',
    'url':'https://www.bigcommerce.com/',
    'vd':'0',
    'deeps':'0'
}
bigw = {
    'name':'Bigware',
    'url':'https://bigware.de',
    'vd':'0',
    'deeps':'0'
}
bizw = {
    'name':'Bizweb',
    'url':'https://www.sapo.vn',
    'vd':'0',
    'deeps':'0'
}
cexec = {
    'name':'Clientexec',
    'url':'https://www.clientexec.com/',
    'vd':'0',
    'deeps':'0'
}
cloudc = {
    'name':'CloudCart',
    'url':'https://cloudcart.com/',
    'vd':'0',
    'deeps':'0'
}
cmshop = {
    'name':'ColorMeShop',
    'url':'https://shop-pro.jp/',
    'vd':'0',
    'deeps':'0'
}

oracle_atg = {
    'name': 'Oracle ATG Web Commerce',
    'url': 'http://www.oracle.com/us/products/applications/atg/web-commerce/web-commerce-search-330138.html',
    'vd': '1',
    'deeps': '0'
}

mdle = {
    'name':'Moodle',
    'url':'https://moodle.com/',
    'vd':'0',
    'deeps':'0'
}

orkis = {
    'name':'ORKIS Ajaris Websuite',
    'url':'http://www.orkis.com/',
    'vd':'0',
    'deeps':'0'
}

cmdia = {
    'name':'Comandia',
    'url':'https://www.comandia.com/',
    'vd':'0',
    'deeps':'0'
}

coms = {
    'name':'Commerce Server',
    'url':'http://commerceserver.net',
    'vd':'1',
    'deeps':'0'
}

cosmos = {
    'name':'Cosmoshop',
    'url':'https://www.cosmoshop.de/',
    'vd':'0',
    'deeps':'0'
}

csc = {
    'name':'CS Cart',
    'url':'https://www.cs-cart.com/',
    'vd':'0',
    'deeps':'0'
}

cubec = {
    'name':'CubeCart',
    'url':'https://www.cubecart.com/',
    'vd':'0',
    'deeps':'0'
}

abda = {
    'name':'Al Mubda',
    'url':'http://www.almubda.net/',
    'vd':'1',
    'deeps':'0'
}

dweb = {
    'name':'Dynamicweb',
    'url':'https://www.dynamicweb.dk/',
    'vd':'1',
    'deeps':'0'
}

ecc = {
    'name':'EC-CUBE',
    'url':'https://www.ec-cube.net/',
    'vd':'0',
    'deeps':'0'
}

elcd = {
    'name':'Elcodi',
    'url':'http://elcodi.io/',
    'vd':'0',
    'deeps':'0'
}

epgs = {
    'name':'ePages',
    'url':'https://epages.com',
    'vd':'0',
    'deeps':'0'
}

ezpub = {
    'name':'eZ Publish',
    'url':'https://ez.no/',
    'vd':'0',
    'deeps':'0'
}

for3 = {
    'name':'Fortune3',
    'url':'https://www.fortune3.com/',
    'vd':'0',
    'deeps':'0'
}

presta = {
    'name':'PrestaShop',
    'url':'https://www.prestashop.com/',
    'vd':'0',
    'deeps':'0'
}

btree = {
    'name':'BigTree CMS',
    'url':'https://www.bigtreecms.org/',
    'vd':'0',
    'deeps':'0'
}

pmoc = {
    'name':'Proximis Omnichannel',
    'url':'https://www.proximis.com',
    'vd':'0',
    'deeps':'0'
}

qcart = {
    'name':'Quick.Cart',
    'url':'https://opensolution.org/shopping-cart-quick-cart.html',
    'vd':'1',
    'deeps':'0'
}

rbsc = {
    'name':'RBS Change',
    'url':'https://www.rbschange.fr/',
    'vd':'1',
    'deeps':'0'
}

sfcc = {
    'name':'Salesforce Commerce Cloud',
    'url':'https://demandware.com/',
    'vd':'0',
    'deeps':'0'
}

sazito = {
    'name':'Sazito',
    'url':'https://sazito.com/',
    'vd':'0',
    'deeps':'0'
}

shopatron = {
    'name':'Shopatron',
    'url':'https://www.shopatron.com',
    'vd':'0',
    'deeps':'0'
}

umbraco = {
    'name':'Umbraco',
    'url':'https://umbraco.com',
    'vd':'1',
    'deeps':'1'
}

shoper = {
    'name':'Shoper',
    'url':'https://www.shoper.pl',
    'vd':'0',
    'deeps':'0'
}

shopery = {
    'name':'Shopery',
    'url':'https://shopery.com/',
    'vd':'0',
    'deeps':'0'
}

shopfa = {
    'name':'ShopFA',
    'url':'https://shopfa.com/',
    'vd':'1',
    'deeps':'0'
}

shopify = {
    'name':'Shopify',
    'url':'https://www.shopify.com/',
    'vd':'0',
    'deeps':'0'
}

shoptet = {
    'name':'Shoptet',
    'url':'https://www.shoptet.cz/',
    'vd':'0',
    'deeps':'0'
}

smartstore = {
    'name':'Smartstore',
    'url':'https://www.smartstore.com',
    'vd':'0',
    'deeps':'0'
}

solusquare = {
    'name':'Solusquare Commerce Cloud',
    'url':'https://www.solusquare.com/',
    'vd':'0',
    'deeps':'0'
}

spree = {
    'name':'Spree',
    'url':'https://spreecommerce.org/',
    'vd':'0',
    'deeps':'0'
}

bitrix = {
    'name':'Bitrix',
    'url':'https://www.1c-bitrix.ru',
    'vd':'0',
    'deeps':'0'
}

brightspot = {
    'name':'Brightspot CMS',
    'url':'https://www.brightspot.com/',
    'vd':'0',
    'deeps':'0'
}

amiro = {
    'name':'Amiro.CMS',
    'url':'https://www.amiro.ru',
    'vd':'1',
    'deeps':'0'
}

weebly = {
    'name':'Weebly',
    'url':'https://www.weebly.com/',
    'vd':'0',
    'deeps':'0'
}

ekmps = {
    'name':'ekmPowershop',
    'url':'https://www.ekm.com/',
    'vd':'0',
    'deeps':'0'
}

godaddywb = {
    'name':'GoDaddy Website Builder',
    'url':'https://godaddy.com/websites/website-builder',
    'vd':'1',
    'deeps':'0'
}

whmcs = {
    'name':'WHMCS',
    'url':'https://www.whmcs.com/',
    'vd':'0',
    'deeps':'0'
}

opennemas = {
    'name':'OpenNemas CMS',
    'url':'https://www.opennemas.com/',
    'vd':'0',
    'deeps':'0'
}

zencart = {
    'name':'Zen Cart CMS',
    'url':'https://www.zen-cart.com/',
    'vd':'0',
    'deeps':'0'
}

ipo = {
    'name':'IPO CMS',
    'url':'https://www.antee.cz/',
    'vd':'0',
    'deeps':'0'
}

hugo = {
    'name':'Hugo',
    'url':'https://gohugo.io/',
    'vd':'1',
    'deeps':'0'
}

squarespace = {
    'name':'Squarespace',
    'url':'https://www.squarespace.com/',
    'vd':'0',
    'deeps':'0'
}

notion = {
    'name':'Notion',
    'url':'https://notion.so',
    'vd':'0',
    'deeps':'0'
}

siquando = {
    'name':'SIQUANDO',
    'url':'https://www.siquando.de/',
    'vd':'0',
    'deeps':'0'
}

freshpage = {
    'name':'Freshpage',
    'url':'https://www.freshpage.ch/',
    'vd':'0',
    'deeps':'0'
}